travel-backpack
===============

.. image:: https://img.shields.io/pypi/v/travel-backpack.svg
    :target: https://pypi.python.org/pypi/travel-backpack
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/borntyping/cookiecutter-pypackage-minimal.png
   :target: https://travis-ci.org/borntyping/cookiecutter-pypackage-minimal
   :alt: Latest Travis CI build status

Some very useful functions and classes to use in day-to-day

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`travel-backpack` was written by `Victor Marcelino <victor.fmarcelino@gmail.com>`_.
